import os
#Following lines specifying, the location of DLLs, are required for Python Versions 3.8 and greater
os.add_dll_directory("C:\BitFlow SDK 6.6\Bin64")
os.add_dll_directory("C:\Program Files\CameraLink\Serial")

import BFModule.BufferAcquisition as Buf
import BFModule.Display as Disp
import numpy as np

import time

def main():

    numBuffers = 10

    CirAq = Buf.clsCircularAcquisition()

    #Call Open board function by showing the Board select dialog
    CirAq.Open()
    print('Board opened.')

    #Allocate the requested number of buffers
    BufArray = CirAq.BufferSetup(numBuffers)

    #Setup acquisition using the default options
    CirAq.AqSetup(Buf.SetupOptions.setupDefault)
    
    disp = Disp.clsDisp(CirAq)
    #Open the display surface
    disp.Open()
    
    #wait for display window to be opened
    while(not disp.isOpen):
        time.sleep(0.001)
    
    CirAq.AqControl(Buf.AcqCommands.Start, Buf.AcqControlOptions.Wait)
    print("Acquisition Started.")
    
    try:
        #while(CirAq.GetAcqStatus().Start == True):
        for i in range(0, 10000):
            CirAq.IssueSoftwareTrigger()
            CurBuf = CirAq.WaitForFrame(0)
            buff = CurBuf.BufferNumber
            img_arr = BufArray[buff]
            ############ Do Math operations here ###############
            time.sleep(1)
            img_arr = img_arr + 10
            ####################################################
            if(disp.isOpen):
                disp.Update(img_arr)
            else:
                break
    except KeyboardInterrupt:
        pass

    print("Stopping acquisition and closing board...")

    #Stop the acquisition
    CirAq.AqControl(Buf.AcqCommands.Stop, Buf.AcqControlOptions.Wait)
    #Close the display surface and free the resources
    disp.Close()
    #Deallocate buffers
    CirAq.BufferCleanup()
    #Close the board
    CirAq.Close()

if __name__ == "__main__":
    main()


